# Interface

Ansible-bender has these commands:

Command | Description
--------|------------
`build` | build a new container image using selected playbook
`list-builds` | list all builds
`get-logs` | display build logs
`inspect` | provide detailed metadata about the selected build
`push` | Push images you built to remote locations.
`clean` | Clean images from database which are no longer present on the disk.
`init` | Adds a template playbook with all the vars.
